package com.hoolai.demo.share;

import android.annotation.TargetApi;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.EditText;
import android.widget.Toast;
import com.hoolai.access.log.LogUtils;
import com.hoolai.fastsdk.demo.R;
import com.hoolai.open.fastaccess.channel.FastSdk;
import com.hoolai.open.fastaccess.channel.callback.FacebookShareCallback;
import com.hoolai.open.fastaccess.channel.callback.FacebookShareType;
import com.hoolai.open.fastaccess.channel.pojo.FaceBookShareData;

/**
 * @author gaor
 * @className: FacebookShareActivity
 * @description TODO 描述 Facebook分享
 * @date 2022/1/17 17:17
 */
public class FacebookShareActivity extends Activity {

    private static final int FILE_SELECT_IMAGE_CODE = 010110;
    private static final int REQUEST_WRITE_STORAGE_PERMISSION = 010111;
    private static final int REQUEST_CODE_OTHER_FILE = 010112;
    private EditText et;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.share_facebook);
        et = findViewById(R.id.et_text_fb);
        et.setText("http://www.baidu.com");

        requestPermission();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (resultCode == RESULT_OK ){
            Uri uri = data.getData();
            LogUtils.e("文件分享路径:"+uri.toString());
            if (requestCode == FILE_SELECT_IMAGE_CODE){
                shareImage(uri.toString());
            }

            if (requestCode == REQUEST_CODE_OTHER_FILE){
                shareVideo(uri.toString());
            }
        }
    }

    /**
     * FacebookShareType：要分享的类型，FacebookShareType.LINK
     * String url：要分享的链接（必须是网络连接）
     * String quote：引文
     * String hashTag：必须以#号开头，类似微博的标签/话题（非必传）
     * FacebookShareCallback：回调
     * @param view
     */
    public void facebookShareLink(View view){
        String url = et.getText().toString();
        if (TextUtils.isEmpty(url)){
            Toast.makeText(FacebookShareActivity.this,"分享连接不能为空!",Toast.LENGTH_SHORT).show();
            return;
        }
        FaceBookShareData data = new FaceBookShareData();
        data.setHashTag("#"+this.getAppName(this));
        data.setQuote(url);
        data.setUrl(url);
        FastSdk.facebookShare(FacebookShareType.LINK,data,new FacebookShareCallback() {
            @Override
            public void onSuccess(String s) {
                Toast.makeText(FacebookShareActivity.this,"分享成功"+s,Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onCancel() {
                Toast.makeText(FacebookShareActivity.this,"取消分享",Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onError(String s) {
                Toast.makeText(FacebookShareActivity.this,"分享失败"+s,Toast.LENGTH_SHORT).show();
            }
        });
    }

    public void facebookShareImage(View view){
        openFileChooser();
    }

    /**
     *  FacebookShareType：要分享的类型,
     *  FacebookShareType.IMAGE
     *  String photoUrl：要分享的图片地址（必须是本地图片路径），可分享1-6张图片
     *  String hashTag：必须以#号开头，类似微博的标签/话题（非必传）
     *  FacebookShareCallback：回调
     * @param path
     */
    public void shareImage(String path){
        if (path==null){
            Toast.makeText(this,"Uri路径不能为空!",Toast.LENGTH_SHORT).show();
            return;
        }
        FaceBookShareData data = new FaceBookShareData();

//        List<String> listBitMap = new ArrayList<>();
//        listBitMap.add(path);

        data.setHashTag("#demo");
//        data.setBitMap(listBitMap);
        data.addBitMap(path);
//        data.addBitMap(photoUrl1);
//        data.addBitMap(photoUrl2);//最多可添加6个图片...
        FastSdk.facebookShare(FacebookShareType.IMAGE,data,new FacebookShareCallback() {
            @Override
            public void onSuccess(String s) {
                Toast.makeText(FacebookShareActivity.this,"分享成功"+s,Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onCancel() {
                Toast.makeText(FacebookShareActivity.this,"取消分享",Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onError(String s) {
                Toast.makeText(FacebookShareActivity.this,"分享失败"+s,Toast.LENGTH_SHORT).show();
            }
        });
    }


    /**
     * 选择图片
     */
    private void openFileChooser() {
        Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
        intent.setType("*/*");
        intent.addCategory(Intent.CATEGORY_OPENABLE);
        try {
            startActivityForResult(Intent.createChooser(intent, "选择文件"), FILE_SELECT_IMAGE_CODE);
            overridePendingTransition(0, 0);
        } catch (Exception ex) {
            LogUtils.e("openFile Chooser:"+ex);
            // Potentially direct the user to the Market with OnProgressChangeListener Dialog
            Toast.makeText(this, "请先安装文件管理器", Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * 选择视频
     * @param view
     */
    public void facebookShareVideo(View view){
        Intent intent = new Intent(Intent.ACTION_OPEN_DOCUMENT);
        intent.addCategory(Intent.CATEGORY_OPENABLE);
        intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true);// 支持多选
        intent.setType("*/*");
        startActivityForResult(Intent.createChooser(intent, "选择文件"), REQUEST_CODE_OTHER_FILE);
    }


    @TargetApi(24)
    public void shareVideo(String path){
        if (path == null){
            Toast.makeText(this,"文件路径不能为空!"+path,Toast.LENGTH_SHORT).show();
            return;
        }
        FaceBookShareData data = new FaceBookShareData();
        data.setHashTag("#"+this.getAppName(this));
        data.setVideoPath(path);
        FastSdk.facebookShare(FacebookShareType.VIDEO,data,new FacebookShareCallback() {
            @Override
            public void onSuccess(String s) {
                Toast.makeText(FacebookShareActivity.this,"分享成功"+s,Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onCancel() {
                Toast.makeText(FacebookShareActivity.this,"取消分享",Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onError(String s) {
                Toast.makeText(FacebookShareActivity.this,"分享失败"+s,Toast.LENGTH_SHORT).show();
            }
        });
    }


    /**
     * 获取应用程序名称
     */
    public static synchronized String getAppName(Context context) {
        try {
            PackageManager packageManager = context.getPackageManager();
            PackageInfo packageInfo = packageManager.getPackageInfo(
                    context.getPackageName(), 0);
            int labelRes = packageInfo.applicationInfo.labelRes;
            return context.getResources().getString(labelRes);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 获取存储权限
     */
    private void requestPermission() {
        /*if (this.checkSelfPermission(FacebookShareActivity.this, Manifest.permission.WRITE_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                requestPermissions(new String[]{Manifest.permission.WRITE_EXTERNAL_STORAGE}, REQUEST_WRITE_STORAGE_PERMISSION);
            } else {
                Toast.makeText(this, "缺少文件读写权限，可能会造成无法分享文件", Toast.LENGTH_SHORT).show();
            }
        }*/
    }
}
